# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

import os
import asyncio
import warnings
from typing import Optional, Union, Dict, Any, Mapping, overload, cast
from typing_extensions import Literal

import httpx

from ._version import __version__
from ._qs import Querystring
from .types import shared_params
from ._utils import extract_files, maybe_transform, required_args, deepcopy_minimal, maybe_coerce_integer, maybe_coerce_float, maybe_coerce_boolean, is_given
from ._types import Omit, NotGiven, Timeout, Transport, ProxiesTypes, RequestOptions, Headers, NoneType, Query, Body, NOT_GIVEN, UnknownResponse
from ._base_client import (
    DEFAULT_LIMITS,
    DEFAULT_TIMEOUT,
    DEFAULT_MAX_RETRIES,
    ResponseT,
    SyncAPIClient,
    AsyncAPIClient,
    make_request_options,
)
from . import resources

import httpx

from ._streaming import AsyncStream as AsyncStream, Stream as Stream

from ._exceptions import DocugamiError, APIStatusError

from typing_extensions import override

from . import _streaming, _exceptions

__all__ = ["Timeout", "Transport", "ProxiesTypes", "RequestOptions", "resources", "Docugami", "AsyncDocugami", "Client", "AsyncClient"]

class Docugami(SyncAPIClient):
    documents: resources.Documents
    docsets: resources.Docsets
    projects: resources.Projects
    workspaces: resources.Workspaces
    webhooks: resources.Webhooks
    with_raw_response: DocugamiWithRawResponse

    # client options
    api_key: str

    def __init__(self, *, api_key: str | None = None, base_url: str | httpx.URL | None = None, timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN, max_retries: int = DEFAULT_MAX_RETRIES, default_headers: Mapping[str, str] | None = None, default_query: Mapping[str, object] | None = None, 
    # Configure a custom httpx client. See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
    http_client: httpx.Client | None = None, 
    # Enable or disable schema validation for data returned by the API.
    # When enabled an error APIResponseValidationError is raised
    # if the API responds with invalid data for the expected schema.
    # 
    # This parameter may be removed or changed in the future.
    # If you rely on this feature, please open a GitHub issue
    # outlining your use-case to help us decide if it should be
    # part of our public interface in the future.
    _strict_response_validation: bool = False) -> None:
        """Construct a new synchronous docugami client instance.

        This automatically infers the `api_key` argument from the `DOCUGAMI_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
          api_key = os.environ.get("DOCUGAMI_API_KEY")
        if api_key is None:
          raise DocugamiError(
            "The api_key client option must be set either by passing api_key to the client or by setting the DOCUGAMI_API_KEY environment variable"
          )
        self.api_key = api_key

        if base_url is None:
          base_url = f"https://api.docugami.com/v1preview1"

        super().__init__(version=__version__, base_url=base_url, max_retries=max_retries, timeout=timeout, http_client=http_client, custom_headers=default_headers, custom_query=default_query, _strict_response_validation=_strict_response_validation)

        self.documents = resources.Documents(self)
        self.docsets = resources.Docsets(self)
        self.projects = resources.Projects(self)
        self.workspaces = resources.Workspaces(self)
        self.webhooks = resources.Webhooks(self)
        self.with_raw_response = DocugamiWithRawResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {
            "Authorization": f"Bearer {api_key}"
        }

    def copy(self, *, api_key: str | None = None, base_url: str | httpx.URL | None = None, timeout: float | Timeout | None | NotGiven = NOT_GIVEN, http_client: httpx.Client | None = None, max_retries: int | NotGiven = NOT_GIVEN, default_headers: Mapping[str, str] | None = None, set_default_headers: Mapping[str, str] | None = None, default_query: Mapping[str, object] | None = None, set_default_query: Mapping[str, object] | None = None) -> Docugami:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.

        It should be noted that this does not share the underlying httpx client class which may lead
        to performance issues.
        """
        if default_headers is not None and set_default_headers is not None:
          raise ValueError(
            'The `default_headers` and `set_default_headers` arguments are mutually exclusive'
          )

        if default_query is not None and set_default_query is not None:
          raise ValueError(
            'The `default_query` and `set_default_query` arguments are mutually exclusive'
          )

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(api_key = api_key or self.api_key, base_url=base_url or str(self.base_url), timeout=self.timeout if isinstance(timeout, NotGiven) else timeout, http_client=http_client, max_retries=max_retries if is_given(max_retries) else self.max_retries, default_headers=headers, default_query=params)

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def __del__(self) -> None:
        if not hasattr(self, '_has_custom_http_client') or not hasattr(self, 'close'):
          # this can happen if the '__init__' method raised an error
          return

        if self._has_custom_http_client:
          return

        self.close()

    @override
    def _make_status_error(self, err_msg: str, *, body: object, response: httpx.Response,) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)

class AsyncDocugami(AsyncAPIClient):
    documents: resources.AsyncDocuments
    docsets: resources.AsyncDocsets
    projects: resources.AsyncProjects
    workspaces: resources.AsyncWorkspaces
    webhooks: resources.AsyncWebhooks
    with_raw_response: AsyncDocugamiWithRawResponse

    # client options
    api_key: str

    def __init__(self, *, api_key: str | None = None, base_url: str | httpx.URL | None = None, timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN, max_retries: int = DEFAULT_MAX_RETRIES, default_headers: Mapping[str, str] | None = None, default_query: Mapping[str, object] | None = None, 
    # Configure a custom httpx client. See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
    http_client: httpx.AsyncClient | None = None, 
    # Enable or disable schema validation for data returned by the API.
    # When enabled an error APIResponseValidationError is raised
    # if the API responds with invalid data for the expected schema.
    # 
    # This parameter may be removed or changed in the future.
    # If you rely on this feature, please open a GitHub issue
    # outlining your use-case to help us decide if it should be
    # part of our public interface in the future.
    _strict_response_validation: bool = False) -> None:
        """Construct a new async docugami client instance.

        This automatically infers the `api_key` argument from the `DOCUGAMI_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
          api_key = os.environ.get("DOCUGAMI_API_KEY")
        if api_key is None:
          raise DocugamiError(
            "The api_key client option must be set either by passing api_key to the client or by setting the DOCUGAMI_API_KEY environment variable"
          )
        self.api_key = api_key

        if base_url is None:
          base_url = f"https://api.docugami.com/v1preview1"

        super().__init__(version=__version__, base_url=base_url, max_retries=max_retries, timeout=timeout, http_client=http_client, custom_headers=default_headers, custom_query=default_query, _strict_response_validation=_strict_response_validation)

        self.documents = resources.AsyncDocuments(self)
        self.docsets = resources.AsyncDocsets(self)
        self.projects = resources.AsyncProjects(self)
        self.workspaces = resources.AsyncWorkspaces(self)
        self.webhooks = resources.AsyncWebhooks(self)
        self.with_raw_response = AsyncDocugamiWithRawResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {
            "Authorization": f"Bearer {api_key}"
        }

    def copy(self, *, api_key: str | None = None, base_url: str | httpx.URL | None = None, timeout: float | Timeout | None | NotGiven = NOT_GIVEN, http_client: httpx.AsyncClient | None = None, max_retries: int | NotGiven = NOT_GIVEN, default_headers: Mapping[str, str] | None = None, set_default_headers: Mapping[str, str] | None = None, default_query: Mapping[str, object] | None = None, set_default_query: Mapping[str, object] | None = None) -> AsyncDocugami:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.

        It should be noted that this does not share the underlying httpx client class which may lead
        to performance issues.
        """
        if default_headers is not None and set_default_headers is not None:
          raise ValueError(
            'The `default_headers` and `set_default_headers` arguments are mutually exclusive'
          )

        if default_query is not None and set_default_query is not None:
          raise ValueError(
            'The `default_query` and `set_default_query` arguments are mutually exclusive'
          )

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(api_key = api_key or self.api_key, base_url=base_url or str(self.base_url), timeout=self.timeout if isinstance(timeout, NotGiven) else timeout, http_client=http_client, max_retries=max_retries if is_given(max_retries) else self.max_retries, default_headers=headers, default_query=params)

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def __del__(self) -> None:
        if not hasattr(self, '_has_custom_http_client') or not hasattr(self, 'close'):
          # this can happen if the '__init__' method raised an error
          return

        if self._has_custom_http_client:
          return

        try:
          asyncio.get_running_loop().create_task(self.close())
        except Exception:
          pass

    @override
    def _make_status_error(self, err_msg: str, *, body: object, response: httpx.Response,) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)

class DocugamiWithRawResponse:
    def __init__(self, client: Docugami) -> None:
        self.documents = resources.DocumentsWithRawResponse(client.documents)
        self.docsets = resources.DocsetsWithRawResponse(client.docsets)
        self.projects = resources.ProjectsWithRawResponse(client.projects)
        self.workspaces = resources.WorkspacesWithRawResponse(client.workspaces)
        self.webhooks = resources.WebhooksWithRawResponse(client.webhooks)

class AsyncDocugamiWithRawResponse:
    def __init__(self, client: AsyncDocugami) -> None:
        self.documents = resources.AsyncDocumentsWithRawResponse(client.documents)
        self.docsets = resources.AsyncDocsetsWithRawResponse(client.docsets)
        self.projects = resources.AsyncProjectsWithRawResponse(client.projects)
        self.workspaces = resources.AsyncWorkspacesWithRawResponse(client.workspaces)
        self.webhooks = resources.AsyncWebhooksWithRawResponse(client.webhooks)

Client = Docugami

AsyncClient = AsyncDocugami